TidGenerator constructor
TidGenerator()
Returns a generator with a random clock identifier and the system clock.
Implementation
TidGenerator() : this.withClockId(Random().nextInt(1 << _clockIdBits));
Returns a generator with a random clock identifier and the system clock.
TidGenerator() : this.withClockId(Random().nextInt(1 << _clockIdBits));