UncheckedAtUri class
final
Properties
-
collection
→ NSID
-
Returns the collection.
no setteroverride
-
collectionOrNull
→ NSID?
-
Returns the collection, or null if this AT URI does not have a
collection segment.
no setteroverride
-
hash
→ String
-
Returns the hash.
no setteroverride
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
hostname
→ String
-
Returns the hostname.
no setteroverride
-
href
→ String
-
Returns the href.
no setteroverride
-
origin
→ String
-
Returns the origin.
no setteroverride
-
pathname
→ String
-
Returns the pathname.
no setteroverride
-
protocol
→ String
-
Returns the protocol.
no setteroverride
-
rkey
→ String
-
Returns the rkey.
no setteroverride
-
rkeyOrNull
→ String?
-
Returns the rkey, or null if this AT URI does not have an rkey
segment.
no setteroverride
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
search
→ String
-
Returns the query string of this AT URI, without the leading
?.
no setteroverride
-
searchParams
→ Map<String, String>
-
Returns the query parameters of this AT URI.
no setteroverride
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override